# Welcome to the Hello, ID Please documentation!

"Hello, ID Please" (HIdP) is a Django application that offers a
full-featured authentication system for Django projects. It is designed with
the OWASP best practices in mind and offers a secure and flexible solution for
registering and authenticating users in Django projects.

## Requirements
* Python >=3.11
* Django >=4.2,<6

# Index
:::{toctree}
:maxdepth: 2
installation
installation-extras
registration
configure-oidc-clients
configure-as-oidc-provider
content-security-policy
user-model
password-validation
one-time-passwords
templates
translations
management-commands
rate-limiting
terms-of-service
:::

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
